DISPLAYMAP_DOCOMO = {'D209i': {'color': 1, 'depth': 256, 'height': 90, 'width': 96},
 'D2101V': {'color': 1, 'depth': 262144, 'height': 130, 'width': 120},
 'D210i': {'color': 1, 'depth': 256, 'height': 91, 'width': 96},
 'D211i': {'color': 1, 'depth': 4096, 'height': 91, 'width': 100},
 'D251i': {'color': 1, 'depth': 262144, 'height': 144, 'width': 132},
 'D251iS': {'color': 1, 'depth': 262144, 'height': 144, 'width': 132},
 'D252i': {'color': 1, 'depth': 262144, 'height': 198, 'width': 176},
 'D253i': {'color': 1, 'depth': 262144, 'height': 198, 'width': 176},
 'D253iWM': {'color': 1, 'depth': 262144, 'height': 144, 'width': 220},
 'D501i': {'color': 0, 'depth': 2, 'height': 72, 'width': 96},
 'D502i': {'color': 1, 'depth': 256, 'height': 90, 'width': 96},
 'D503i': {'color': 1, 'depth': 4096, 'height': 126, 'width': 132},
 'D503iS': {'color': 1, 'depth': 4096, 'height': 126, 'width': 132},
 'D504i': {'color': 1, 'depth': 262144, 'height': 144, 'width': 132},
 'D505i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'D505iS': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'D506i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'D701i': {'color': 1, 'depth': 65536, 'height': 240, 'width': 230},
 'D701iWM': {'color': 1, 'depth': 65536, 'height': 240, 'width': 230},
 'D702i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D702iBCL': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D702iF': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D703i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D704i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D705i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'D705imyu': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'D800iDS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D851iWM': {'color': 1, 'depth': 262144, 'height': 320, 'width': 230},
 'D900i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'D901i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D901iS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'D902i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 230},
 'D902iS': {'color': 1, 'depth': 262144, 'height': 320, 'width': 230},
 'D903i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 230},
 'D903iTV': {'color': 1, 'depth': 262144, 'height': 320, 'width': 230},
 'D904i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'D905i': {'color': 1, 'depth': 262144, 'height': 352, 'width': 240},
 'ER209i': {'color': 0, 'depth': 2, 'height': 72, 'width': 120},
 'F2051': {'color': 1, 'depth': 65536, 'height': 182, 'width': 176},
 'F209i': {'color': 1, 'depth': 256, 'height': 91, 'width': 96},
 'F2102V': {'color': 1, 'depth': 65536, 'height': 182, 'width': 176},
 'F210i': {'color': 1, 'depth': 256, 'height': 113, 'width': 96},
 'F211i': {'color': 1, 'depth': 4096, 'height': 113, 'width': 96},
 'F212i': {'color': 1, 'depth': 65536, 'height': 136, 'width': 132},
 'F251i': {'color': 1, 'depth': 65536, 'height': 140, 'width': 132},
 'F501i': {'color': 0, 'depth': 2, 'height': 84, 'width': 112},
 'F502i': {'color': 1, 'depth': 256, 'height': 91, 'width': 96},
 'F502it': {'color': 1, 'depth': 256, 'height': 91, 'width': 96},
 'F503i': {'color': 1, 'depth': 256, 'height': 130, 'width': 120},
 'F503iS': {'color': 1, 'depth': 4096, 'height': 130, 'width': 120},
 'F504i': {'color': 1, 'depth': 65536, 'height': 136, 'width': 132},
 'F504iS': {'color': 1, 'depth': 65536, 'height': 136, 'width': 132},
 'F505i': {'color': 1, 'depth': 262144, 'height': 268, 'width': 240},
 'F505iGPS': {'color': 1, 'depth': 262144, 'height': 268, 'width': 240},
 'F506i': {'color': 1, 'depth': 262144, 'height': 268, 'width': 240},
 'F661i': {'color': 1, 'depth': 65536, 'height': 136, 'width': 132},
 'F671i': {'color': 1, 'depth': 256, 'height': 126, 'width': 120},
 'F671iS': {'color': 1, 'depth': 65536, 'height': 120, 'width': 160},
 'F672i': {'color': 1, 'depth': 65536, 'height': 120, 'width': 160},
 'F700i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F700iS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F702iD': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F703i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F704i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F705i': {'color': 1, 'depth': 262144, 'height': 352, 'width': 240},
 'F801i': {'color': 1, 'depth': 65536, 'height': 352, 'width': 240},
 'F880iES': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F881iES': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F882iES': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F883i': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F883iES': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F883iESS': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F883iS': {'color': 1, 'depth': 65536, 'height': 256, 'width': 240},
 'F884i': {'color': 1, 'depth': 262144, 'height': 364, 'width': 240},
 'F900i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F900iC': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F900iT': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F901iC': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F901iS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F902i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F902iS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F903i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F903iBSC': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F903iX': {'color': 1, 'depth': 262144, 'height': 240, 'width': 230},
 'F904i': {'color': 1, 'depth': 262144, 'height': 352, 'width': 240},
 'F905i': {'color': 1, 'depth': 16777216, 'height': 352, 'width': 240},
 'F905iBiz': {'color': 1, 'depth': 16777216, 'height': 352, 'width': 240},
 'F906i': {'color': 1, 'depth': 16777216, 'height': 352, 'width': 240},
 'KO209i': {'color': 1, 'depth': 256, 'height': 96, 'width': 96},
 'KO210i': {'color': 1, 'depth': 256, 'height': 96, 'width': 96},
 'L600i': {'color': 1, 'depth': 65536, 'height': 189, 'width': 170},
 'L601i': {'color': 1, 'depth': 65536, 'height': 189, 'width': 170},
 'L602i': {'color': 1, 'depth': 65536, 'height': 189, 'width': 170},
 'L704i': {'color': 1, 'depth': 262144, 'height': 280, 'width': 240},
 'L705i': {'color': 1, 'depth': 262144, 'height': 280, 'width': 240},
 'L705iX': {'color': 1, 'depth': 262144, 'height': 280, 'width': 240},
 'L852i': {'color': 1, 'depth': 65536, 'height': 298, 'width': 240},
 'M702iG': {'color': 1, 'depth': 262144, 'height': 267, 'width': 240},
 'M702iS': {'color': 1, 'depth': 262144, 'height': 267, 'width': 240},
 'N2001': {'color': 1, 'depth': 4096, 'height': 128, 'width': 118},
 'N2002': {'color': 1, 'depth': 65536, 'height': 128, 'width': 118},
 'N2051': {'color': 1, 'depth': 65536, 'height': 198, 'width': 176},
 'N209i': {'color': 0, 'depth': 4, 'height': 82, 'width': 108},
 'N2102V': {'color': 1, 'depth': 65536, 'height': 198, 'width': 176},
 'N210i': {'color': 1, 'depth': 256, 'height': 113, 'width': 118},
 'N211i': {'color': 1, 'depth': 4096, 'height': 128, 'width': 118},
 'N211iS': {'color': 1, 'depth': 4096, 'height': 128, 'width': 118},
 'N251i': {'color': 1, 'depth': 65536, 'height': 140, 'width': 132},
 'N251iS': {'color': 1, 'depth': 65536, 'height': 140, 'width': 132},
 'N252i': {'color': 1, 'depth': 65536, 'height': 140, 'width': 132},
 'N253i': {'color': 1, 'depth': 65536, 'height': 180, 'width': 160},
 'N2701': {'color': 1, 'depth': 65536, 'height': 198, 'width': 176},
 'N501i': {'color': 0, 'depth': 2, 'height': 128, 'width': 118},
 'N502i': {'color': 0, 'depth': 4, 'height': 128, 'width': 118},
 'N502it': {'color': 1, 'depth': 256, 'height': 128, 'width': 118},
 'N503i': {'color': 1, 'depth': 4096, 'height': 128, 'width': 118},
 'N503iS': {'color': 1, 'depth': 4096, 'height': 128, 'width': 118},
 'N504i': {'color': 1, 'depth': 65536, 'height': 180, 'width': 160},
 'N504iS': {'color': 1, 'depth': 65536, 'height': 180, 'width': 160},
 'N505i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N505iS': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N506i': {'color': 1, 'depth': 262144, 'height': 295, 'width': 240},
 'N506iS': {'color': 1, 'depth': 262144, 'height': 295, 'width': 240},
 'N506iSII': {'color': 1, 'depth': 262144, 'height': 295, 'width': 240},
 'N600i': {'color': 1, 'depth': 65536, 'height': 180, 'width': 176},
 'N601i': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N700i': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N701i': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N701iECO': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N702iD': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N702iS': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N703iD': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N703imyu': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N704imyu': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N705i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'N705imyu': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'N821i': {'color': 0, 'depth': 4, 'height': 128, 'width': 118},
 'N900i': {'color': 1, 'depth': 65536, 'height': 269, 'width': 240},
 'N900iG': {'color': 1, 'depth': 65536, 'height': 269, 'width': 240},
 'N900iL': {'color': 1, 'depth': 65536, 'height': 269, 'width': 240},
 'N900iS': {'color': 1, 'depth': 65536, 'height': 269, 'width': 240},
 'N901iC': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N901iS': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'N902i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N902iL': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N902iS': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N902iX': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N903i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'N904i': {'color': 1, 'depth': 262144, 'height': 352, 'width': 240},
 'N905i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'N905iBiz': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'N905imyu': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'N906imyu': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'NM502i': {'color': 0, 'depth': 2, 'height': 106, 'width': 111},
 'NM705i': {'color': 1, 'depth': 16777216, 'height': 235, 'width': 231},
 'NM850iG': {'color': 1, 'depth': 65536, 'height': 144, 'width': 176},
 'P2002': {'color': 1, 'depth': 65536, 'height': 128, 'width': 118},
 'P209i': {'color': 0, 'depth': 4, 'height': 87, 'width': 96},
 'P209iS': {'color': 1, 'depth': 256, 'height': 87, 'width': 96},
 'P2101V': {'color': 1, 'depth': 262144, 'height': 182, 'width': 163},
 'P2102V': {'color': 1, 'depth': 262144, 'height': 198, 'width': 176},
 'P210i': {'color': 1, 'depth': 256, 'height': 91, 'width': 96},
 'P211i': {'color': 1, 'depth': 65536, 'height': 130, 'width': 120},
 'P211iS': {'color': 1, 'depth': 65536, 'height': 130, 'width': 120},
 'P213i': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P251iS': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P252i': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P252iS': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P253i': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P253iS': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P501i': {'color': 0, 'depth': 2, 'height': 120, 'width': 96},
 'P502i': {'color': 0, 'depth': 4, 'height': 117, 'width': 96},
 'P503i': {'color': 1, 'depth': 256, 'height': 130, 'width': 120},
 'P503iS': {'color': 1, 'depth': 256, 'height': 130, 'width': 120},
 'P504i': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P504iS': {'color': 1, 'depth': 65536, 'height': 144, 'width': 132},
 'P505i': {'color': 1, 'depth': 65536, 'height': 266, 'width': 240},
 'P505iS': {'color': 1, 'depth': 65536, 'height': 266, 'width': 240},
 'P506iC': {'color': 1, 'depth': 65536, 'height': 266, 'width': 240},
 'P506iCII': {'color': 1, 'depth': 65536, 'height': 266, 'width': 240},
 'P651ps': {'color': 0, 'depth': 4, 'height': 87, 'width': 96},
 'P700i': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'P701iD': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'P702i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P702iD': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P703i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P703imyu': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P704i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P704imyu': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P705i': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P705iCL': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P705imyu': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P821i': {'color': 0, 'depth': 4, 'height': 128, 'width': 118},
 'P851i': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'P900i': {'color': 1, 'depth': 65536, 'height': 266, 'width': 240},
 'P900iV': {'color': 1, 'depth': 262144, 'height': 266, 'width': 240},
 'P901i': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'P901iS': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'P901iTV': {'color': 1, 'depth': 65536, 'height': 270, 'width': 240},
 'P902i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P902iS': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P903i': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P903iTV': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P903iX': {'color': 1, 'depth': 262144, 'height': 270, 'width': 240},
 'P904i': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P905i': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P905iTV': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'P906i': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'R209i': {'color': 0, 'depth': 4, 'height': 72, 'width': 96},
 'R211i': {'color': 1, 'depth': 4096, 'height': 98, 'width': 96},
 'R691i': {'color': 0, 'depth': 4, 'height': 72, 'width': 96},
 'R692i': {'color': 1, 'depth': 4096, 'height': 98, 'width': 96},
 'SA700iS': {'color': 1, 'depth': 65536, 'height': 252, 'width': 240},
 'SA702i': {'color': 1, 'depth': 65536, 'height': 252, 'width': 240},
 'SA800i': {'color': 1, 'depth': 65536, 'height': 252, 'width': 240},
 'SH2101V': {'color': 1, 'depth': 65536, 'height': 600, 'width': 800},
 'SH251i': {'color': 1, 'depth': 65536, 'height': 130, 'width': 120},
 'SH251iS': {'color': 1, 'depth': 65536, 'height': 187, 'width': 176},
 'SH252i': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH505i': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH505iS': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH506iC': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH700i': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH700iS': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH702iD': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'SH702iS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'SH703i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'SH704i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH705i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH705iII': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH821i': {'color': 1, 'depth': 256, 'height': 78, 'width': 96},
 'SH851i': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH900i': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH901iC': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH901iS': {'color': 1, 'depth': 262144, 'height': 252, 'width': 240},
 'SH902i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'SH902iS': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'SH902iSL': {'color': 1, 'depth': 262144, 'height': 240, 'width': 240},
 'SH903i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH903iTV': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH904i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH905i': {'color': 1, 'depth': 16777216, 'height': 320, 'width': 240},
 'SH905iTV': {'color': 1, 'depth': 16777216, 'height': 320, 'width': 240},
 'SH906i': {'color': 1, 'depth': 16777216, 'height': 320, 'width': 240},
 'SO210i': {'color': 1, 'depth': 256, 'height': 113, 'width': 120},
 'SO211i': {'color': 1, 'depth': 4096, 'height': 112, 'width': 120},
 'SO212i': {'color': 1, 'depth': 65536, 'height': 112, 'width': 120},
 'SO213i': {'color': 1, 'depth': 65536, 'height': 112, 'width': 120},
 'SO213iS': {'color': 1, 'depth': 65536, 'height': 112, 'width': 120},
 'SO213iWR': {'color': 1, 'depth': 65536, 'height': 112, 'width': 120},
 'SO502i': {'color': 0, 'depth': 4, 'height': 120, 'width': 120},
 'SO502iWM': {'color': 1, 'depth': 256, 'height': 113, 'width': 120},
 'SO503i': {'color': 1, 'depth': 65536, 'height': 113, 'width': 120},
 'SO503iS': {'color': 1, 'depth': 65536, 'height': 113, 'width': 120},
 'SO504i': {'color': 1, 'depth': 65536, 'height': 112, 'width': 120},
 'SO505i': {'color': 1, 'depth': 262144, 'height': 240, 'width': 256},
 'SO505iS': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO506i': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO506iC': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO506iS': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO702i': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO703i': {'color': 1, 'depth': 262144, 'height': 368, 'width': 240},
 'SO704i': {'color': 1, 'depth': 262144, 'height': 368, 'width': 240},
 'SO705i': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SO902i': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO902iWP+': {'color': 1, 'depth': 262144, 'height': 256, 'width': 240},
 'SO903i': {'color': 1, 'depth': 262144, 'height': 368, 'width': 240},
 'SO903iTV': {'color': 1, 'depth': 262144, 'height': 368, 'width': 240},
 'SO905i': {'color': 1, 'depth': 16777216, 'height': 368, 'width': 240},
 'SO905iCS': {'color': 1, 'depth': 16777216, 'height': 368, 'width': 240},
 'SO906i': {'color': 1, 'depth': 16777216, 'height': 368, 'width': 240},
 'T2101V': {'color': 1, 'depth': 262144, 'height': 144, 'width': 176},
 'F01A': {'color': 1, 'depth': 16777216, 'height': 352, 'width': 240},
 'P01A': {'color': 1, 'depth': 262144, 'height': 350, 'width': 240},
 'N01A': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'N03A': {'color': 1, 'depth': 262144, 'height': 320, 'width': 240},
 'SH01A': {'color': 1, 'depth': 16777216, 'height': 320, 'width': 240},
}
